==> theia-0.1.1-py3-none-any.whl: theia/aws/security/kms.py <==
import pulumi

from pulumi_aws import kms

from typing import Optional, Literal, Mapping

from theia import ResourceOptions
from theia.utils.logger import Logger
from theia.registry import StackRegistry
from theia.definitions import THEIA_VERSION

logger = Logger("kms")


class Key:
    def __new__(
        cls,
        resource_name: str,
        description: Optional[str] = None,
        customer_master_key_spec: Optional[
            Literal[
                "SYMMETRIC_DEFAULT",
                "RSA_2048",
                "RSA_3072",
                "RSA_4096",
                "HMAC_256",
                "ECC_NIST_P256",
                "ECC_NIST_P384",
                "ECC_NIST_P521",
                "ECC_SECG_P256K1",
            ]
        ] = "SYMMETRIC_DEFAULT",
        deletion_window_in_days: Optional[int] = 30,
        enable_key_rotation: Optional[bool] = False,
        is_enabled: Optional[bool] = True,
        key_usage: Optional[
            Literal["ENCRYPT_DECRYPT", "SIGN_VERIFY", "GENERATE_VERIFY_MAC"]
        ] = "ENCRYPT_DECRYPT",
        multi_region: Optional[bool] = False,
        policy: Optional[str] = None,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> kms.Key:
        merged_tags = THEIA_VERSION
        name = {"Name": resource_name}
        if tags:
            merged_tags = {**tags, **name, **merged_tags}

        logger.info(f"creating resource kms key {resource_name}")
        kms_key = kms.Key(
            resource_name,
            description=description,
            customer_master_key_spec=customer_master_key_spec,
            deletion_window_in_days=deletion_window_in_days,
            enable_key_rotation=enable_key_rotation,
            is_enabled=is_enabled,
            key_usage=key_usage,
            multi_region=multi_region,
            policy=policy,
            opts=opts,
        )

        pulumi.export(
            f"kms---{resource_name}",
            {"id": kms_key.id, "arn": kms_key.arn, "key-id": kms_key.key_id},
        )
        return kms_key

    @staticmethod
    def import_(stack: str, resource_name: str) -> kms.Key:
        stack_ref = StackRegistry.get(stack_name=stack)
        key = stack_ref.get_output(name=f"kms---{resource_name}")
        return kms.Key.get(resource_name=resource_name, id=key["id"])

==> theia-0.1.2-py3-none-any.whl: theia/aws/security/kms.py <==
import pulumi

from pulumi_aws import kms

from typing import Optional, Literal, Mapping

from theia import ResourceOptions
from theia.definitions import THEIA_VERSION
from theia.registry import StackRegistry, GlobalTags


class Key:
    def __new__(
        cls,
        resource_name: str,
        description: Optional[str] = None,
        customer_master_key_spec: Optional[
            Literal[
                "SYMMETRIC_DEFAULT",
                "RSA_2048",
                "RSA_3072",
                "RSA_4096",
                "HMAC_256",
                "ECC_NIST_P256",
                "ECC_NIST_P384",
                "ECC_NIST_P521",
                "ECC_SECG_P256K1",
            ]
        ] = "SYMMETRIC_DEFAULT",
        deletion_window_in_days: Optional[int] = 30,
        enable_key_rotation: Optional[bool] = False,
        is_enabled: Optional[bool] = True,
        key_usage: Optional[
            Literal["ENCRYPT_DECRYPT", "SIGN_VERIFY", "GENERATE_VERIFY_MAC"]
        ] = "ENCRYPT_DECRYPT",
        multi_region: Optional[bool] = False,
        policy: Optional[str] = None,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> kms.Key:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        kms_key = kms.Key(
            resource_name,
            description=description,
            customer_master_key_spec=customer_master_key_spec,
            deletion_window_in_days=deletion_window_in_days,
            enable_key_rotation=enable_key_rotation,
            is_enabled=is_enabled,
            key_usage=key_usage,
            multi_region=multi_region,
            policy=policy,
            opts=opts,
        )

        pulumi.export(
            f"kms---{resource_name}",
            {"id": kms_key.id, "arn": kms_key.arn, "key-id": kms_key.key_id},
        )
        return kms_key

    @staticmethod
    def import_(stack: str, resource_name: str) -> kms.Key:
        stack_ref = StackRegistry.get(stack_name=stack)
        key = stack_ref.get_output(name=f"kms---{resource_name}")
        return kms.Key.get(resource_name=resource_name, id=key["id"])
